@@ -127,8 +127,8 @@ class Connection(AbstractChannel):
                 and (password is not None):
             login_response = AMQPWriter()
             login_response.write_table({'LOGIN': userid, 'PASSWORD': password})
-            login_response = login_response.getvalue()[4:]  # Skip the length
-                                                            # at the beginning
+            # Skip the length at the beginning
+            login_response = login_response.getvalue()[4:]
 
         d = dict(LIBRARY_PROPERTIES, **client_properties or {})
         self._method_override = {(60, 50): self._dispatch_basic_return}
@@ -162,7 +162,7 @@ class Connection(AbstractChannel):
         # Let the transport.py module setup the actual
         # socket connection to the broker.
         #
-        self.transport = create_transport(host, connect_timeout, ssl)
+        self.transport = self.Transport(host, connect_timeout, ssl)
 
         self.method_reader = MethodReader(self.transport)
         self.method_writer = MethodWriter(self.transport, self.frame_max)
@@ -182,6 +182,9 @@ class Connection(AbstractChannel):
 
         return self._x_open(virtual_host)
 
+    def Transport(self, host, connect_timeout, ssl=False):
+        return create_transport(host, connect_timeout, ssl)
+
     @property
     def connected(self):
         return self.transport and self.transport.connected
@@ -335,7 +338,7 @@ class Connection(AbstractChannel):
                 # http://bugs.python.org/issue10272
                 if 'timed out' in str(exc):
                     raise socket.timeout()
-               # Non-blocking SSL sockets can throw SSLError
+                # Non-blocking SSL sockets can throw SSLError
                 if 'The operation did not complete' in str(exc):
                     raise socket.timeout()
                 raise
